==> vue-layout-builder-0.0.9.tgz: package/tests/unit/components/LayoutBuilderElementsOverlay.spec.js <==
import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vue from "vue/dist/vue";
import Vuex from "vuex";
import ElementsOverlay from "../../../src/components/LayoutBuilderElementsOverlay.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();

localVue.use(Vuex);

describe("ElementsOverlay.vue", () => {
  describe("", () => {
    const activeGroupInContentTypesOverlay = "foo";
    const contentTypesOverlayVisibility = true;
    const wrapper = shallowMount(ElementsOverlay, {
      store: Store(
        Object.assign(state, {
          activeGroupInContentTypesOverlay,
          contentTypesOverlayVisibility
        })
      ),
      localVue
    });

    describe("activeGroup()", () => {
      it("returns activeGroupInContentTypesOverlay from the state", () => {
        expect(wrapper.vm.activeGroup).toBe(activeGroupInContentTypesOverlay);
      });
    });

    describe("isHidden()", () => {
      it("returns the opposite of contentTypesOverlayVisibility from the state", () => {
        expect(wrapper.vm.isHidden).toBe(!contentTypesOverlayVisibility);
      });
    });

    describe("groups()", () => {
      it("returns an array from the group keys in content_types", () => {
        expect(wrapper.vm.groups).toEqual(["Bar group", "Foo group"]);
      });
    });

    describe("groupsWithContentTypes()", () => {
      it("returns an array from the group keys in content_types with the related content_types", () => {
        expect(wrapper.vm.groupsWithContentTypes).toEqual([
          {
            name: "Bar group",
            content_types: [
              {
                id: 2,
                name: "Media Player",
                group: "Bar group",
                url: "test.html"
              },
              {
                id: 3,
                name: "PDF",
                group: "Bar group",
                url: "test.html"
              }
            ]
          },
          {
            name: "Foo group",
            content_types: [
              {
                id: 1,
                name: "Documentation Center",
                group: "Foo group",
                url: "test.html"
              }
            ]
          }
        ]);
      });
    });
  });

  describe("clicking on the overlay", () => {
    const store = Store(state);
    const wrapper = shallowMount(ElementsOverlay, {
      store,
      localVue
    });
    const stub = jest.fn();

    wrapper.setMethods({ onBackgroundClick: stub });

    it("calls onBackgroundClick()", () => {
      wrapper.trigger("click");
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling onBackgroundClick", () => {
    describe("with the clicked event being the root element", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      wrapper.setMethods({ close: stub });

      it("calls close()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element
        });
        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the clicked event not being the root element", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      wrapper.setMethods({ close: stub });

      it("does not call close()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element.firstChild
        });
        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("close()", () => {
    it("dispatches closeElementsOverlay on the store", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.dispatch = stub;

      wrapper.vm.close();
      expect(stub).toHaveBeenCalledWith("closeElementsOverlay");
    });
  });

  describe("calling onKeyDown", () => {
    describe("with the keyCode being 27", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.dispatch = stub;

      it("dispatches closeElementsOverlay on the store", () => {
        wrapper.vm.onKeyDown({
          keyCode: 27
        });

        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the keyCode not being 27", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.dispatch = stub;

      it("does not dispatch closeElementsOverlay on the store", () => {
        wrapper.vm.onKeyDown({
          keyCode: 13
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("calling onGroupNameKeyDown", () => {
    describe("with the keyCode being 13 or 32", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      const stub2 = jest.fn();
      const group = "foo";

      wrapper.setMethods({ setActiveGroup: stub });

      describe("13", () => {
        it("calls setActiveGroup()", () => {
          wrapper.vm.onGroupNameKeyDown(
            {
              keyCode: 13,
              preventDefault: stub2
            },
            group
          );

          expect(stub).toHaveBeenCalledWith(group);
          expect(stub2).toHaveBeenCalled();
        });
      });

      describe("32", () => {
        it("calls setActiveGroup()", () => {
          wrapper.vm.onGroupNameKeyDown(
            {
              keyCode: 32,
              preventDefault: stub2
            },
            group
          );

          expect(stub).toHaveBeenCalledWith(group);
          expect(stub2).toHaveBeenCalled();
        });
      });
    });

    describe("with the keyCode not being 13 or 32", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ setActiveGroup: stub });

      it("does not call setActiveGroup()", () => {
        wrapper.vm.onKeyDown({
          keyCode: 27
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("checkIfGroupIsActive()", () => {
    const activeGroupInContentTypesOverlay = "foo";
    const wrapper = shallowMount(ElementsOverlay, {
      store: Store(
        state,
        Object.assign({
          activeGroupInContentTypesOverlay
        })
      ),
      localVue
    });

    describe("with the given group being this.activeGroup", () => {
      it("returns true", () => {
        expect(
          wrapper.vm.checkIfGroupIsActive({
            name: activeGroupInContentTypesOverlay
          })
        ).toBe(true);
      });
    });

    describe("with the given group not being this.activeGroup", () => {
      it("returns false", () => {
        expect(wrapper.vm.checkIfGroupIsActive({ name: "bar" })).toBe(false);
      });
    });
  });

  describe("setActiveGroup()", () => {
    describe("with the given group being not current one", () => {
      const activeGroupInContentTypesOverlay = "foo";
      const store = Store(
        state,
        Object.assign({
          activeGroupInContentTypesOverlay
        })
      );
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.commit = stub;

      it("commits setActiveGroupInContentTypesOverlay to the store with the group name", () => {
        wrapper.vm.setActiveGroup({ name: activeGroupInContentTypesOverlay });
        expect(stub).toHaveBeenCalledWith(
          "setActiveGroupInContentTypesOverlay",
          null
        );
      });
    });

    describe("with the given group being the current one", () => {
      const activeGroupInContentTypesOverlay = "foo";
      const store = Store(
        state,
        Object.assign({
          activeGroupInContentTypesOverlay
        })
      );
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.commit = stub;

      it("commits setActiveGroupInContentTypesOverlay to the store with null", () => {
        wrapper.vm.setActiveGroup({ name: "bar" });
        expect(stub).toHaveBeenCalledWith(
          "setActiveGroupInContentTypesOverlay",
          "bar"
        );
      });
    });
  });

  describe("chooseContentType()", () => {
    const url = "foo";
    const store = Store(state);
    const wrapper = shallowMount(ElementsOverlay, {
      store,
      localVue
    });
    const stub = jest.fn();
    store.commit = stub;

    it("commits setIframeSrc with the contentType url to the store", () => {
      wrapper.vm.chooseContentType({ url });
      expect(stub).toHaveBeenCalledWith("setIframeSrc", url);
    });

    it("commits setContentTypesOverlayVisibility with the false to the store", () => {
      wrapper.vm.chooseContentType({ url });
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("change isHidden", () => {
    describe("to true", () => {
      const store = Store(
        Object.assign(state, {
          contentTypesOverlayVisibility: true
        })
      );
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub1 = jest.fn();
      const stub2 = jest.fn();
      store.commit = stub1;
      wrapper.setMethods({ removeKeyDownListener: stub2 });

      Vue.set(store.state, "contentTypesOverlayVisibility", false);

      it("commits setActiveGroupInContentTypesOverlay with null to the store", () => {
        expect(stub1).toHaveBeenCalledWith(
          "setActiveGroupInContentTypesOverlay",
          null
        );
      });

      it("calls removeKeyDownListener()", () => {
        expect(stub2).toHaveBeenCalled();
      });
    });

    describe("to false", () => {
      let store;
      let wrapper;
      let stub1;
      let stub2;

      beforeEach(() => {
        store = Store(
          Object.assign(state, {
            contentTypesOverlayVisibility: false
          })
        );
        wrapper = shallowMount(ElementsOverlay, {
          store,
          localVue
        });
        stub1 = jest.fn();
        stub2 = jest.fn();
        store.commit = stub1;
      });

      it("commits setActiveGroupInContentTypesOverlay with null to the store", () => {
        Vue.set(store.state, "contentTypesOverlayVisibility", true);
        expect(stub1).not.toHaveBeenCalled();
      });

      it("calls addKeyDownListener()", () => {
        wrapper.setMethods({ addKeyDownListener: stub2 });
        Vue.set(store.state, "contentTypesOverlayVisibility", true);
        expect(stub2).toHaveBeenCalled();
      });
    });
  });

  describe("calling addKeyDownListener()", () => {
    let store;
    let wrapper;
    let stub;

    beforeEach(() => {
      store = Store(state);
      wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      stub = jest.fn();
      wrapper.setMethods({ onKeyDown: stub });
    });

    it("adds a keydown listener and calls onKeyDown()", () => {
      wrapper.vm.addKeyDownListener();
      window.dispatchEvent(new Event("keydown"));
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling removeKeyDownListener()", () => {
    let store;
    let wrapper;
    let stub;

    beforeEach(() => {
      store = Store(state);
      wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      stub = jest.fn();
      wrapper.setMethods({ onKeyDown: stub });
    });

    it("removes the keydown listener and doesn't call onKeyDown()", () => {
      wrapper.vm.addKeyDownListener();
      wrapper.vm.removeKeyDownListener();
      window.dispatchEvent(new Event("keydown"));
      expect(stub).not.toHaveBeenCalled();
    });
  });
});

==> vue-layout-builder-0.0.15.tgz: package/tests/unit/components/LayoutBuilderElementsOverlay.spec.js <==
import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vue from "vue/dist/vue";
import Vuex from "vuex";
import ElementsOverlay from "../../../src/components/LayoutBuilderElementsOverlay.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();

localVue.use(Vuex);

describe("ElementsOverlay.vue", () => {
  describe("", () => {
    const activeGroupInElementsOverlay = "foo";
    const contentTypesOverlayVisibility = true;
    const wrapper = shallowMount(ElementsOverlay, {
      store: Store(
        Object.assign(state, {
          activeGroupInElementsOverlay,
          contentTypesOverlayVisibility
        })
      ),
      localVue
    });

    describe("activeGroup()", () => {
      it("returns activeGroupInElementsOverlay from the state", () => {
        expect(wrapper.vm.activeGroup).toBe(activeGroupInElementsOverlay);
      });
    });

    describe("isHidden()", () => {
      it("returns the opposite of contentTypesOverlayVisibility from the state", () => {
        expect(wrapper.vm.isHidden).toBe(!contentTypesOverlayVisibility);
      });
    });

    describe("groupNames()", () => {
      it("returns an array from the group keys in content_types", () => {
        expect(wrapper.vm.groupNames).toEqual(["Bar group", "Foo group"]);
      });
    });

    describe("groupsWithContentTypes()", () => {
      it("returns an array from the group keys in content_types with the related content_types", () => {
        expect(wrapper.vm.groupsWithContentTypes).toEqual([
          {
            name: "Bar group",
            content_types: [
              {
                id: 2,
                name: "Media Player",
                group: "Bar group",
                url: "test.html"
              },
              {
                id: 3,
                name: "PDF",
                group: "Bar group",
                url: "test.html"
              }
            ]
          },
          {
            name: "Foo group",
            content_types: [
              {
                id: 1,
                name: "Documentation Center",
                group: "Foo group",
                url: "test.html"
              }
            ]
          }
        ]);
      });
    });
  });

  describe("clicking on the overlay", () => {
    const store = Store(state);
    const wrapper = shallowMount(ElementsOverlay, {
      store,
      localVue
    });
    const stub = jest.fn();

    wrapper.setMethods({ onBackgroundClick: stub });

    it("calls onBackgroundClick()", () => {
      wrapper.trigger("click");
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling onBackgroundClick", () => {
    describe("with the clicked event being the root element", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      wrapper.setMethods({ close: stub });

      it("calls close()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element
        });
        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the clicked event not being the root element", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      wrapper.setMethods({ close: stub });

      it("does not call close()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element.firstChild
        });
        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("close()", () => {
    it("dispatches closeElementsOverlay on the store", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.dispatch = stub;

      wrapper.vm.close();
      expect(stub).toHaveBeenCalledWith("closeElementsOverlay");
    });
  });

  describe("calling onKeyDown", () => {
    describe("with the keyCode being 27", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.dispatch = stub;

      it("dispatches closeElementsOverlay on the store", () => {
        wrapper.vm.onKeyDown({
          keyCode: 27
        });

        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the keyCode not being 27", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.dispatch = stub;

      it("does not dispatch closeElementsOverlay on the store", () => {
        wrapper.vm.onKeyDown({
          keyCode: 13
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("calling onGroupNameKeyDown", () => {
    describe("with the keyCode being 13 or 32", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      const stub2 = jest.fn();
      const group = "foo";
      const section = "content_type";

      wrapper.setMethods({ setActiveGroup: stub });

      describe("13", () => {
        it("calls setActiveGroup()", () => {
          wrapper.vm.onGroupNameKeyDown(
            {
              keyCode: 13,
              preventDefault: stub2
            },
            section,
            group
          );

          expect(stub).toHaveBeenCalledWith(section, group);
          expect(stub2).toHaveBeenCalled();
        });
      });

      describe("32", () => {
        it("calls setActiveGroup()", () => {
          wrapper.vm.onGroupNameKeyDown(
            {
              keyCode: 32,
              preventDefault: stub2
            },
            section,
            group
          );

          expect(stub).toHaveBeenCalledWith(section, group);
          expect(stub2).toHaveBeenCalled();
        });
      });
    });

    describe("with the keyCode not being 13 or 32", () => {
      const store = Store(state);
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ setActiveGroup: stub });

      it("does not call setActiveGroup()", () => {
        wrapper.vm.onKeyDown({
          keyCode: 27
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("checkIfGroupIsActive()", () => {
    const section = "element";
    const group = "foo";
    const store = Store(
      Object.assign(state, {
        activeGroupInElementsOverlay: `${section}_${group}`
      })
    );
    const wrapper = shallowMount(ElementsOverlay, {
      store,
      localVue
    });

    describe("with the given group being this.activeGroup", () => {
      it("returns true", () => {
        expect(
          wrapper.vm.checkIfGroupIsActive(section, {
            name: group
          })
        ).toBe(true);
      });
    });

    describe("with the given group not being this.activeGroup", () => {
      it("returns false", () => {
        expect(wrapper.vm.checkIfGroupIsActive(section, { name: "bar" })).toBe(
          false
        );
      });
    });
  });

  describe("setActiveGroup()", () => {
    describe("with the given group being not current one", () => {
      const section = "element";
      const group = "foo";
      const store = Store(
        Object.assign(state, {
          activeGroupInElementsOverlay: `${section}_${group}`
        })
      );
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.commit = stub;

      it("commits setActiveGroupInElementsOverlay to the store with the group name", () => {
        wrapper.vm.setActiveGroup(section, {
          name: "bar"
        });
        expect(stub).toHaveBeenCalledWith(
          "setActiveGroupInElementsOverlay",
          `${section}_bar`
        );
      });
    });

    describe("with the given group being the current one", () => {
      const section = "element";
      const group = "foo";
      const store = Store(
        Object.assign(state, {
          activeGroupInElementsOverlay: `${section}_${group}`
        })
      );
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub = jest.fn();
      store.commit = stub;

      it("commits setActiveGroupInElementsOverlay to the store with null", () => {
        wrapper.vm.setActiveGroup(section, { name: group });
        expect(stub).toHaveBeenCalledWith(
          "setActiveGroupInElementsOverlay",
          null
        );
      });
    });
  });

  describe("chooseContentType()", () => {
    const url = "foo";
    const store = Store(state);
    const wrapper = shallowMount(ElementsOverlay, {
      store,
      localVue
    });
    const stub = jest.fn();
    store.commit = stub;

    it("commits setIframeSrc with the contentType url to the store", () => {
      wrapper.vm.chooseContentType({ url });
      expect(stub).toHaveBeenCalledWith("setIframeSrc", url);
    });

    it("commits setContentTypesOverlayVisibility with the false to the store", () => {
      wrapper.vm.chooseContentType({ url });
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("change isHidden", () => {
    describe("to true", () => {
      const store = Store(
        Object.assign(state, {
          contentTypesOverlayVisibility: true
        })
      );
      const wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      const stub1 = jest.fn();
      const stub2 = jest.fn();
      store.commit = stub1;
      wrapper.setMethods({ removeKeyDownListener: stub2 });

      Vue.set(store.state, "contentTypesOverlayVisibility", false);

      it("commits setActiveGroupInElementsOverlay with null to the store", () => {
        expect(stub1).toHaveBeenCalledWith(
          "setActiveGroupInElementsOverlay",
          null
        );
      });

      it("calls removeKeyDownListener()", () => {
        expect(stub2).toHaveBeenCalled();
      });
    });

    describe("to false", () => {
      let store;
      let wrapper;
      let stub1;
      let stub2;

      beforeEach(() => {
        store = Store(
          Object.assign(state, {
            contentTypesOverlayVisibility: false
          })
        );
        wrapper = shallowMount(ElementsOverlay, {
          store,
          localVue
        });
        stub1 = jest.fn();
        stub2 = jest.fn();
        store.commit = stub1;
      });

      it("commits setActiveGroupInElementsOverlay with null to the store", () => {
        Vue.set(store.state, "contentTypesOverlayVisibility", true);
        expect(stub1).not.toHaveBeenCalled();
      });

      it("calls addKeyDownListener()", () => {
        wrapper.setMethods({ addKeyDownListener: stub2 });
        Vue.set(store.state, "contentTypesOverlayVisibility", true);
        expect(stub2).toHaveBeenCalled();
      });
    });
  });

  describe("calling addKeyDownListener()", () => {
    let store;
    let wrapper;
    let stub;

    beforeEach(() => {
      store = Store(state);
      wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      stub = jest.fn();
      wrapper.setMethods({ onKeyDown: stub });
    });

    it("adds a keydown listener and calls onKeyDown()", () => {
      wrapper.vm.addKeyDownListener();
      window.dispatchEvent(new Event("keydown"));
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling removeKeyDownListener()", () => {
    let store;
    let wrapper;
    let stub;

    beforeEach(() => {
      store = Store(state);
      wrapper = shallowMount(ElementsOverlay, {
        store,
        localVue
      });
      stub = jest.fn();
      wrapper.setMethods({ onKeyDown: stub });
    });

    it("removes the keydown listener and doesn't call onKeyDown()", () => {
      wrapper.vm.addKeyDownListener();
      wrapper.vm.removeKeyDownListener();
      window.dispatchEvent(new Event("keydown"));
      expect(stub).not.toHaveBeenCalled();
    });
  });
});
